Struct rkyv::niche::option_box::ArchivedOptionBox [−][src]
#[repr(transparent)]pub struct ArchivedOptionBox<T: ArchivePointee + ?Sized> { /* fields omitted */ }Expand description
A niched archived Option<Box<T>>.
It uses less space by storing the None variant as a null pointer.
Implementations
Converts to an Option<&ArchivedBox<T>>.
Converts to an Option<&mut ArchivedBox<T>>.
Converts from Pin<&ArchivedOptionBox<T>> to Option<Pin<&ArchivedBox<T>>>.
Converts from Pin<&mut ArchivedOption<T>> to Option<Pin<&mut ArchivedBox<T>>>.
Returns an iterator over the possibly contained value.
Returns a mutable iterator over the possibly contained value.
pub unsafe fn resolve_from_option<U: ArchiveUnsized<Archived = T> + ?Sized>(
field: Option<&U>,
pos: usize,
resolver: OptionBoxResolver<U::MetadataResolver>,
out: *mut Self
)
pub unsafe fn resolve_from_option<U: ArchiveUnsized<Archived = T> + ?Sized>(
field: Option<&U>,
pos: usize,
resolver: OptionBoxResolver<U::MetadataResolver>,
out: *mut Self
)
Resolves an ArchivedOptionBox<T::Archived> from an Option<&T>.
Safety
posmust be the position ofoutwithin the archiveresolvermust be the result of serializingfield
pub fn serialize_from_option<U, S>(
field: Option<&U>,
serializer: &mut S
) -> Result<OptionBoxResolver<U::MetadataResolver>, S::Error> where
U: SerializeUnsized<S, Archived = T> + ?Sized,
S: Serializer + ?Sized,
pub fn serialize_from_option<U, S>(
field: Option<&U>,
serializer: &mut S
) -> Result<OptionBoxResolver<U::MetadataResolver>, S::Error> where
U: SerializeUnsized<S, Archived = T> + ?Sized,
S: Serializer + ?Sized,
Serializes an ArchivedOptionBox<T::Archived> from an Option<&T>.